zipline-django-pyodbc-azure
=============================

.. image:: http://img.shields.io/pypi/v/django-pyodbc-azure.svg?style=flat
    :target: https://pypi.python.org/pypi/django-pyodbc-azure

.. image:: http://img.shields.io/pypi/l/django-pyodbc-azure.svg?style=flat
    :target: http://opensource.org/licenses/BSD-3-Clause

*zipline-django-pyodbc-azure* is a modern fork of
`django-pyodbc-azure <https://github.com/michiya/django-pyodbc-azure>`